### Name: ShowModels
### Title: Interactive Choice of Models and Parameters
### Aliases: ShowModels
### Keywords: spatial

### ** Examples

# first example: one-dimensional simulations

# system("xset b off") ## for unix systems

RFparameters(Print=1)
x <-  seq(1,10,0.1);
ShowModels(x=x)

# second example: two-dimensional simulations and
#                 empirical variogram
dx <- runif(300,0,8)
dy <- runif(300,0,8)
dz <- GaussRF(x=dx, y=dy, grid=FALSE, model="gaus",
      param=c(1,2,1,2))
ev <- EmpiricalVariogram(x=dx, y=dy, data=dz, grid=FALSE,
      bin=(-1:20)/4)
x <-  seq(1,5,0.1);
ShowModels(x=x, y=x, empirical=ev)

# third example: two-dimensional anistropic simulations and
#                link function
x <- seq(1,10,0.1)

ShowModels(x=x, y=x, link=function(x) x^2,
          model=list(list(model="exp", var=1, aniso=c(1,0,0,5))))

x <-  seq(1,10,0.1)
ShowModels(x=x, link=function(x) x^2,
           model=list(list(model="exp",var=1, scale=1)))

x <-  seq(1,10,0.1)
RFparameters(CE.force=TRUE, CE.trials=1, CE.mmin=-4, CE.userfft=FALSE)
ShowModels(x=x, link="MaxStable", fixed.rs=TRUE,
           model=list(list(model="gauss",var=1, scale=1)), type="l")




